@@ -25,8 +25,10 @@
 class Interface;
 class DBusServer : public StrigiThread {
 private:
+    int quitpipe[2];
     Interface* interface;
     void* run(void*);   
+    void stopThread();
 public:
     explicit DBusServer(Interface* i) :StrigiThread("DBusServer"),
         interface(i) {}
