@@ -26,21 +26,43 @@
 
 class Event;
 
+/*!
+* @class EventListenerQueue
+* @brief A collector of all event instances
+*
+* All Event occurrencies are stored here. Interested classes can retrieve them using getEvents method.
+*
+* In a producer-consumer pattern EventListenerQueue is the place where all producer store the products
+*/
 class EventListenerQueue
 {
     public:
-        EventListenerQueue();
+        explicit EventListenerQueue();
         ~EventListenerQueue();
-       
+        
+        /*!
+        * @param events a vector containing new Events to manage
+        */
         void addEvents (std::vector<Event*> events);
+        
+        /*!
+        * @return the number of events availables
+        */
         unsigned int size() { return m_events.size(); }
+        
+        /*!
+        * @return a vector containing all events, after that m_events is cleared
+        */
         std::vector <Event*> getEvents();
        
     protected:
+        /*!
+        * deallocate all events stored into m_events. In the end m_events will be empty.
+        */
         void clear();
        
-        std::map <std::string, Event*> m_events;
-        pthread_mutex_t m_mutex;
+        std::map <std::string, Event*> m_events; //!< all event instances
+        pthread_mutex_t m_mutex;//!< mutex lock over m_events
 };
 
 #endif
