@@ -19,6 +19,8 @@
  */
 #include "jstreamsconfig.h"
 #include "indexer.h"
+#include "filtermanager.h"
+#include "dummyindexwriter.h"
 
 void
 printUsage(char** argv) {
@@ -39,8 +41,10 @@ main(int argc, char **argv) {
         }
         verbosity = atoi(argv[2]);
     }
-        
-    Indexer indexer(verbosity);
+    
+    FilterManager filtermanager;
+    DummyIndexWriter writer(verbosity);    
+    Indexer indexer(&filtermanager, &writer);
     indexer.index(argv[argc-1]);
     return 0;
 }
