@@ -21,14 +21,14 @@
 #define INDEXER_H
 
 #include <string>
-#include "filelister.h"
 #include "streamindexer.h"
-#include "dummyindexwriter.h"
+
+class FileLister;
+class FilterManager;
 
 class Indexer {
 private:
-    FileLister m_lister;
-    DummyIndexWriter writer;
+    FileLister* m_lister;
     jstreams::StreamIndexer m_indexer;
 
     static bool addFileCallback(const char* fullpath, uint dirlen,
@@ -36,7 +36,8 @@ private:
     static Indexer *workingIndexer;
     void doFile(const char* filepath);
 public:
-    Indexer(int verbosity) :writer(verbosity), m_indexer(&writer) {}
+    Indexer(FilterManager* filtermanager, jstreams::IndexWriter* writer);
+    ~Indexer();
     void index(const char *dir);
 };
 
