@@ -19,14 +19,42 @@
  */
 #include "jstreamsconfig.h"
 #include "indexer.h"
+#include "filtermanager.h"
+#include <sys/types.h>
+#include <dirent.h>
 
+bool
+containsHelp(int argc, char **argv) {
+    for (int i=1; i<argc; ++i) {
+         if (strcmp(argv[i], "--help") == 0
+             || strcmp(argv[i], "-h") == 0) return true;
+    }
+    return false;
+}
+void
+checkIndexdirIsEmpty(const char* dir) {
+    DIR* d = opendir(dir);
+    struct dirent* de = readdir(d);
+    while (de) {
+        if (strcmp(de->d_name, "..") && strcmp(de->d_name, ".")) {
+            fprintf(stderr, "Directory %s is not empty.\n", dir);
+            exit(1);
+        }
+        de = readdir(d);
+    }
+    closedir(d);
+}
 int
 main(int argc, char **argv) {
-    if (argc != 3) {
-        printf("Usage: %s [indexdir] [dir-to-index]\n", argv[0]);
+    if (containsHelp(argc, argv) || argc != 3) {
+        fprintf(stderr, "Usage: %s [indexdir] [dir-to-index]\n", argv[0]);
         return -1;
     }
-        Indexer indexer(argv[1]);
+
+    checkIndexdirIsEmpty(argv[1]);
+    
+    FilterManager filtermanager;
+    Indexer indexer(argv[1], &filtermanager);
     indexer.index(argv[2]);
     return 0;
 }
