@@ -34,8 +34,8 @@ public:
     std::string mimetype;
     std::string sha1;
     int64_t size;
-    time_t mtime;
-    std::map<std::string, std::string> properties;
+    uint64_t mtime;
+    std::multimap<std::string, std::string> properties;
 };
 
 }
