@@ -37,7 +37,8 @@ private:
     bool checkMagic();
 public:
     enum ZipFormat { ZLIBFORMAT, GZIPFORMAT, ZIPFORMAT};
-    GZipInputStream(StreamBase<char>* input, ZipFormat format=GZIPFORMAT);
+    explicit GZipInputStream(StreamBase<char>* input,
+        ZipFormat format=GZIPFORMAT);
     ~GZipInputStream();
     int32_t fillBuffer(char* start, int32_t space);
 };
